.. This is part of the Photini documentation.
   Copyright (C)  2012-15  Jim Easterbrook.
   See the file ../DOC_LICENSE.txt for copying condidions.

Miscellaneous
=============

.. toctree::
   :maxdepth: 3

   changelog
   licence
   doc_licence
